@@ -152,19 +152,14 @@ public class GrizzlyActivator extends HousekeepingActivator {
             serverConfiguration.setMaxRequestParameters(grizzlyConfig.getMaxRequestParameters());
 
             final NetworkListener networkListener = new NetworkListener("http-listener", grizzlyConfig.getHttpHost(), grizzlyConfig.getHttpPort());
-            networkListener.getKeepAlive().setIdleTimeoutInSeconds(-1);
 
             /*-
-             * Set the maximum size of the POST body generated by an HTML form
-             * 
-             * Interferes with "com.openexchange.servlet.maxBodySize"
+             * Set the maximum size of the PUT/POST body generated by an HTML form to honor "com.openexchange.servlet.maxBodySize"
              */
-            {
-                final ConfigurationService service = getService(ConfigurationService.class);
-                final int maxFormPostSize = null == service ? -1 : service.getIntProperty("com.openexchange.http.grizzly.maxFormPostSize", -1);
-                networkListener.setMaxFormPostSize(maxFormPostSize);
-            }
-            
+            int maxBodySize = grizzlyConfig.getMaxBodySize();
+            networkListener.setMaxFormPostSize(maxBodySize);
+            networkListener.setMaxBufferedPostSize(maxBodySize);
+                
             if (grizzlyConfig.isAJPEnabled()) {
                 if (LOG.isInfoEnabled()) {
                     LOG.info("Enabling AJP for Grizzly server.");
