@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011-2013 Oracle and/or its affiliates. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common Development
@@ -138,8 +138,7 @@ public class DefaultServlet extends HttpServlet {
             resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
         }
 
-        addToFileCache(req, resource);
-        sendFile(resp, resource);
+        sendFile(req, resp, resource);
 
 
     }
@@ -177,7 +176,9 @@ public class DefaultServlet extends HttpServlet {
 
     // --------------------------------------------------------- Private Methods
 
-    public static void sendFile(final HttpServletResponse response, final File file)
+    private void sendFile(final HttpServletRequest request,
+                          final HttpServletResponse response,
+                          final File file)
             throws IOException {
         final String path = file.getPath();
         FileInputStream fis = null;
@@ -214,7 +215,7 @@ public class DefaultServlet extends HttpServlet {
             if (length <= Integer.MAX_VALUE) {
                 response.setContentLength((int) length);
             }
-
+            addToFileCache(request, file);
 
             final OutputStream out = response.getOutputStream();
 
